@@ -48,6 +48,7 @@ class Py2NDevice:
             self._initializing = False
 
     async def update(self) -> None:
+        """Update device data."""
         try:
             info: dict[str, Any] = await get_info(self.aiohttp_session, self.options)
             status: dict[str, Any] = await get_status(
@@ -80,6 +81,10 @@ class Py2NDevice:
             raise
 
     async def restart(self) -> None:
+        """Restart device."""
+        if not self.initialized:
+            raise NotInitialized
+        
         try:
             await restart(self.aiohttp_session, self.options)
         except Py2NError as err:
@@ -87,6 +92,10 @@ class Py2NDevice:
             raise
 
     async def audio_test(self) -> None:
+        """Test audio."""
+        if not self.initialized:
+            raise NotInitialized
+
         try:
             await test_audio(self.aiohttp_session, self.options)
         except Py2NError as err:
@@ -94,6 +103,10 @@ class Py2NDevice:
             raise
 
     async def set_switch(self, switch_id, on) -> None:
+        """Set switch status."""
+        if not self.initialized:
+            raise NotInitialized
+
         if not self._data.switches:
             raise Py2NError("no switches configured")
 
@@ -107,6 +120,10 @@ class Py2NDevice:
             raise
 
     def get_switch(self, switch_id) -> bool:
+        """Get switch status."""
+        if not self.initialized:
+            raise NotInitialized
+
         if not self._data.switches:
             raise Py2NError("no switches configured")
 
@@ -116,6 +133,10 @@ class Py2NDevice:
         return self._data.switches[switch_id - 1].active
 
     async def close(self) -> None:
+        """Close http session."""
+        if not self.initialized:
+            raise NotInitialized
+
         await self.aiohttp_session.close()
 
     @property
